# Generated by `rjournal_article()` using `knitr::purl()`: do not edit by hand
# Please edit did2s.Rmd to modify this file

## ----setup, include = F-------------------------------------------------------
library(did2s)
library(ggplot2)
par(family = "HersheySans") # Nicer fonts for base R plots


## ---- echo = T, eval = F------------------------------------------------------
#> did2s(data, yname, first_stage, second_stage,
#>       treatment, cluster_var, weights = NULL,
#>       bootstrap = FALSE, n_bootstraps = 250,
#>       verbose = TRUE)


## ---- results = 'hide'--------------------------------------------------------
data(df_het, package = "did2s")


## ----ex-data, echo = F, fig.width = 6, fig.height = 4, out.width="100%", fig.cap = "Example data with heterogeneous and dynamic treatment effects. Each line represents the average outcome in a given year for each group. In the absence of treatment, all three groups would exhibit parallel trends."----
# Mean for treatment group-year
agg <- aggregate(df_het$dep_var, by=list(g = df_het$g, year = df_het$year), FUN = mean)

agg$g <- as.character(agg$g)
agg$g <- ifelse(agg$g == "0", "Never Treated", agg$g)

never <- agg[agg$g == "Never Treated", ]
g1 <- agg[agg$g == "2000", ]
g2 <- agg[agg$g == "2010", ]


plot(0, 0, xlim = c(1990,2020), ylim = c(2, 8), type = "n",
     main = "Data-generating Process", ylab = "Outcome", xlab = "Year")
lines(never$year, never$x, col = "#8e549f", type = "b", pch = 15)
lines(g1$year, g1$x, col = "#497eb3", type = "b", pch = 17)
lines(g2$year, g2$x, col = "#d2382c", type = "b", pch = 16)
legend(x = 1990, y = 8, col = c("#8e549f", "#497eb3", "#d2382c"), 
       pch = c(15, 17, 16),
       legend = c("Not Treated", "2000", "2010"))




## ----static, cache = T--------------------------------------------------------
static = did2s(
	data = df_het, 
	yname = "dep_var", 
	treatment = "treat",
    first_stage = ~ 0 | unit + year, 
    second_stage = ~ i(treat, ref = FALSE),
    cluster_var = "unit", 
	verbose = FALSE
)

summary(static)


## ----static-output-html, include = knitr::is_html_output()--------------------
fixest::etable(static, fitstat = c("n"),
  title = "Estimate of Static TWFE Model", 
  notes = "Standard errors clustered at unit level.
Estimated using Two-Stage Difference-in-Differences.
proposed by Gardner (2021).")


## ----static-output-tex, include = knitr::is_latex_output(), results = "asis"----
fixest::etable(static, fitstat = c("n"), tex = TRUE,
               title = "Estimate of Static TWFE Model", 
               notes = "Standard errors clustered at unit level. 
Estimated using Two-Stage Difference-in-Differences.
proposed by Gardner (2021).")


## ----dynamic, cache = T, fig.width = 6, fig.height = 4, out.width = "100%", fig.cap = "Event-study Estimate of TWFE Model. Standard Errors clustered at unit level. Estimated using the Two-Stage Difference-in-Differences proposed by Gardner (2021)."----
es = did2s(
	data = df_het, 
	yname = "dep_var", 
	treatment = "treat",
	first_stage = ~ 0 | unit + year, 
    second_stage = ~ i(rel_year, ref = c(-1, Inf)),
    cluster_var = "unit", 
	verbose = FALSE
)

fixest::iplot(
	es, 
	main = "Event study: Staggered treatment", 
	xlab = "Relative time to treatment", 
	col = "steelblue", ref.line = -0.5
)

# Add the (mean) true effects
true_effects = tapply((df_het$te + df_het$te_dynamic), df_het$rel_year, mean)
true_effects = head(true_effects, -1)
points(-20:20, true_effects, pch = 20, col = "grey60")

# Legend
legend(x=-20, y=3, col = c("steelblue", "grey60"), 
       pch = c(20, 20), 
       legend = c("Two-stage estimate", "True effect"))


## ----dynamic-w-twfe, fig.width = 6, fig.height = 4, out.width = "100%", fig.cap = "Event-study Estimate of TWFE Model. Standard Errors clustered at unit level. Estimated using the Two-Stage Difference-in-Differences proposed by Gardner (2021) and a Traditional TWFE model."----

twfe = feols(dep_var ~ i(rel_year, ref=c(-1, Inf)) | unit + year, data = df_het) 

fixest::iplot(list(es, twfe), sep = 0.2, ref.line = -0.5,
      col = c("steelblue", "#82b446"), pt.pch = c(20, 18), 
      xlab = "Relative time to treatment", 
      main = "Event study: Staggered treatment (comparison)")

# True Effects
points(-20:20, true_effects, pch = 20, col = "grey60")

# Legend
legend(x=-20, y=3, col = c("steelblue", "#82b446", "grey60"), pch = c(20, 18, 20), 
       legend = c("Two-stage estimate", "TWFE", "True Effect"))


## ---- echo = T, eval = F------------------------------------------------------
#> event_study(
#> 	data, yname, idname, tname, gname,
#> 	estimator,
#> 	xformla = NULL, horizon = NULL, weights = NULL
#> )


## ----estimators-html, echo = F, layout="l-page", include = knitr::is_html_output()----
methods <- tibble::tribble(
  ~Estimator, ~`R package and Estimator Option`, ~Type, ~`Comparison group`, ~`Main Assumptions`, ~`Uniform inference of estimates`,
  "Gardner (2021)", "<code>{did2s}</code>", "Imputes \\(Y(0)\\)", "Not-yet- and/or Never-treated", "<ul><li>Parallel Trends for all units</li><li>Limited anticipation<sup>*</sup></li><li>Correct specification of \\(Y(0)\\)</li></ul>", "",
  "Borusyak, Jaravel, and Spiess (2021)", "<code>{didimputation}</code>", "Imputes \\(Y(0)\\)", "Not-yet- and/or Never-treated", "<ul><li>Parallel Trends for all units</li><li>Limited anticipation<sup>*</sup></li><li>Correct specification of \\(Y(0)\\)</li></ul>", "",
  "Callaway and Sant'Anna (2021)", "<code>{did}</code>", "2x2 Aggregation", "Either Not-yet- or Never-treated", "<ul><li>Parallel Trends for Not-yet-treated <i>or</i> Never-treated</li><li>Limited anticipation<sup>*</sup></li></ul>", "✔",
  "Sun and Abraham (2020)", "<code>{fixest/sunab}</code>", "2x2 Aggregation", "Not-yet- and/or Never-treated", "<ul><li>Parallel Trends for all units</li><li>Limited anticipation<sup>*</sup></li></ul>", "",
  "Roth and Sant'Anna (2021)", "<code>{staggered}</code>", "2x2 Aggregation", "Not-yet-treated", "<ul><li>Treatment timing is random</li><li>Limited anticipation<sup>*</sup></ul>", "",
) |> 
  dplyr::mutate(`Main Assumptions` = purrr::map(`Main Assumptions`, gt::html))

gt::gt(methods, caption="Event Study Estimators") |>
  gt::cols_align(
    align = "center",
    columns = c(`Uniform inference of estimates`)
  ) |> 
  gt::tab_options(
  	table.font.size = 16,
    data_row.padding = gt::px(10),
    table.width = gt::px(1000),
    source_notes.font.size = gt::px(14)
  ) |>
  gt::fmt_markdown(
  	columns = c(`Main Assumptions`, `R package and Estimator Option`, `Estimator`)
  ) |>
  gt::tab_source_note(
    source_note = gt::html("This table summarizes the differences between various proposed event-study estimators in the econometric literature.<br/><sup>*</sup> Anticipation can be accounted for by adjusting 'initial treatment day' back \\(x\\) periods, where \\(x\\) is the number of periods before treatment that anticipation can occur.")
  )


## ----estimators-latex, results = "asis", echo = F, layout="l-page", include = knitr::is_latex_output()----
cat(r"(
\begin{landscape}
\begin{table}
\caption{Event Study Estimators \label{tab:estimators-latex}}
\begin{threeparttable}

\begin{tabular}{p{0.2\textwidth}llp{0.2\textwidth}p{0.4\textwidth}c}
\toprule
\multicolumn{1}{l}{Estimator} & \multicolumn{1}{l}{R package /} & \multicolumn{1}{l}{Type} & \multicolumn{1}{l}{Comparison group} & \multicolumn{1}{l}{Main Assumptions} & \multicolumn{1}{l}{Uniform inference} \\
 & \multicolumn{1}{l}{\texttt{estimator} argument} & & & & \\

\midrule
Gardner (2021) 
& \texttt{did2s} 
& Imputes $Y(0)$ 
& Not-yet- and/or Never-treated 
& 
\vspace{-5mm}
\begin{itemize}[leftmargin=*]
  \item Parallel Trends for all units
  \item Limited anticipation${^*}$
  \item Correct specification of $Y(0)$
\end{itemize}
& \\

Borusyak, Jaravel, and Spiess (2021) 
& \texttt{didimputation} 
& Imputes $Y(0)$ 
& Not-yet- and/or Never-treated 
& 
\vspace{-5mm}
\begin{itemize}[leftmargin=*]
  \item Parallel Trends for all units
  \item Limited anticipation${^*}$
  \item Correct specification of $Y(0)$
\end{itemize}
& \\

Callaway and Sant'Anna (2021) 
& \texttt{did} 
& 2$\times$2 Aggregation 
& Either Not-yet- or Never-treated 
& 
\vspace{-5mm}
\begin{itemize}[leftmargin=*]
  \item Parallel Trends for Not-yet-treated {\it or} Never-treated
  \item Limited anticipation${^*}$
\end{itemize}
& Yes \\

Sun and Abraham (2020) 
& \texttt{fixest}/\texttt{sunab}
& 2$\times$2 Aggregation 
& Not-yet- and/or Never-treated 
& 
\vspace{-5mm}
\begin{itemize}[leftmargin=*]
  \item Parallel Trends for all units
  \item Limited anticipation${^*}$
\end{itemize}
& \\

Roth and Sant'Anna (2021) 
& \texttt{staggered} 
& 2$\times$2 Aggregation 
& Not-yet-treated 
& 
\vspace{-5mm}
\begin{itemize}[leftmargin=*]
  \item Treatment timing is random
  \item Limited anticipation${^*}$
\end{itemize}
& \\
\bottomrule
\end{tabular}

\begin{tablenotes}
\item This table summarizes the differences between various proposed event-study estimators in the econometric literature.
\item[$^{*}$]  Anticipation can be accounted for by adjusting 'initial treatment day' back $x$ periods, where $x$ is the number of periods before treatment that anticipation can occur.
\end{tablenotes}

\end{threeparttable}
\end{table}
\end{landscape}
)")


## ----es-estimate, cache=TRUE, collapse=TRUE-----------------------------------
data(df_het, package = "did2s")
out = event_study(
  data = df_het, yname = "dep_var", idname = "unit",
  tname = "year", gname = "g", estimator = "all"
)

head(out)


## ----es-alternatives, cache=TRUE, fig.width = 12, fig.height = 8, out.width = "100%", layout="l-page", fig.cap=ifelse(knitr::is_html_output(), "Event-study Estimators. This figure plots the results from the event_study command on example data.", "Event-study Estimators. This figure plots the results from the event\\_study command on example data.")----

plot_event_study(out, horizon = c(-5,10))


